# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aom_framework/protocols.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='aom_framework/protocols.proto',
  package='aom_api',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1d\x61om_framework/protocols.proto\x12\x07\x61om_api\x1a\x19google/protobuf/any.proto\"L\n\x08\x45nvState\x12\x0f\n\x07tick_id\x18\x01 \x01(\x04\x12/\n\x11\x65nv_specific_data\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"@\n\rEnvStateDelta\x12/\n\x11\x65nv_specific_data\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"\r\n\x0bRewardEvent\"D\n\x11TrialStartRequest\x12/\n\x11\x65nv_specific_data\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"\x97\x01\n\x0fTrialStartReply\x12/\n\x11\x65nv_specific_data\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\tplayer_id\x18\x02 \x01(\x04\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12,\n\x11initial_sim_state\x18\x04 \x01(\x0b\x32\x11.aom_api.EnvState\"\x14\n\x12TrialActionRequest\"\x12\n\x10TrialActionReply\"\x14\n\x12TrialRewardRequest\"\x12\n\x10TrialRewardReply\"W\n\x0f\x45nvStartRequest\x12\x30\n\x0cuser_request\x18\x01 \x01(\x0b\x32\x1a.aom_api.TrialStartRequest\x12\x12\n\nsession_id\x18\x02 \x01(\t\"Q\n\rEnvStartReply\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12,\n\x11initial_sim_state\x18\x02 \x01(\x0b\x32\x11.aom_api.EnvState\"\x91\x02\n\x10\x45nvUpdateRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x35\n\tuser_data\x18\x02 \x03(\x0b\x32\".aom_api.EnvUpdateRequest.UserData\x12\x37\n\nagent_data\x18\x03 \x03(\x0b\x32#.aom_api.EnvUpdateRequest.AgentData\x1a;\n\x08UserData\x12/\n\x11\x65nv_specific_data\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x1a<\n\tAgentData\x12/\n\x11\x65nv_specific_data\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"7\n\x0e\x45nvUpdateReply\x12%\n\x05\x64\x65lta\x18\x01 \x01(\x0b\x32\x16.aom_api.EnvStateDelta\"U\n\x11\x41gentStartRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12,\n\x11initial_sim_state\x18\x02 \x01(\x0b\x32\x11.aom_api.EnvState\"\x11\n\x0f\x41gentStartReply\"\x14\n\x12\x41gentRewardRequest\"\x12\n\x10\x41gentRewardReplyb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])




_ENVSTATE = _descriptor.Descriptor(
  name='EnvState',
  full_name='aom_api.EnvState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tick_id', full_name='aom_api.EnvState.tick_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='env_specific_data', full_name='aom_api.EnvState.env_specific_data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=145,
)


_ENVSTATEDELTA = _descriptor.Descriptor(
  name='EnvStateDelta',
  full_name='aom_api.EnvStateDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='env_specific_data', full_name='aom_api.EnvStateDelta.env_specific_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=211,
)


_REWARDEVENT = _descriptor.Descriptor(
  name='RewardEvent',
  full_name='aom_api.RewardEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=226,
)


_TRIALSTARTREQUEST = _descriptor.Descriptor(
  name='TrialStartRequest',
  full_name='aom_api.TrialStartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='env_specific_data', full_name='aom_api.TrialStartRequest.env_specific_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=296,
)


_TRIALSTARTREPLY = _descriptor.Descriptor(
  name='TrialStartReply',
  full_name='aom_api.TrialStartReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='env_specific_data', full_name='aom_api.TrialStartReply.env_specific_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='player_id', full_name='aom_api.TrialStartReply.player_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.TrialStartReply.session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_sim_state', full_name='aom_api.TrialStartReply.initial_sim_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=450,
)


_TRIALACTIONREQUEST = _descriptor.Descriptor(
  name='TrialActionRequest',
  full_name='aom_api.TrialActionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=452,
  serialized_end=472,
)


_TRIALACTIONREPLY = _descriptor.Descriptor(
  name='TrialActionReply',
  full_name='aom_api.TrialActionReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=492,
)


_TRIALREWARDREQUEST = _descriptor.Descriptor(
  name='TrialRewardRequest',
  full_name='aom_api.TrialRewardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=514,
)


_TRIALREWARDREPLY = _descriptor.Descriptor(
  name='TrialRewardReply',
  full_name='aom_api.TrialRewardReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=516,
  serialized_end=534,
)


_ENVSTARTREQUEST = _descriptor.Descriptor(
  name='EnvStartRequest',
  full_name='aom_api.EnvStartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_request', full_name='aom_api.EnvStartRequest.user_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.EnvStartRequest.session_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=623,
)


_ENVSTARTREPLY = _descriptor.Descriptor(
  name='EnvStartReply',
  full_name='aom_api.EnvStartReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.EnvStartReply.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_sim_state', full_name='aom_api.EnvStartReply.initial_sim_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=706,
)


_ENVUPDATEREQUEST_USERDATA = _descriptor.Descriptor(
  name='UserData',
  full_name='aom_api.EnvUpdateRequest.UserData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='env_specific_data', full_name='aom_api.EnvUpdateRequest.UserData.env_specific_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=861,
  serialized_end=920,
)

_ENVUPDATEREQUEST_AGENTDATA = _descriptor.Descriptor(
  name='AgentData',
  full_name='aom_api.EnvUpdateRequest.AgentData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='env_specific_data', full_name='aom_api.EnvUpdateRequest.AgentData.env_specific_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=922,
  serialized_end=982,
)

_ENVUPDATEREQUEST = _descriptor.Descriptor(
  name='EnvUpdateRequest',
  full_name='aom_api.EnvUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.EnvUpdateRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_data', full_name='aom_api.EnvUpdateRequest.user_data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agent_data', full_name='aom_api.EnvUpdateRequest.agent_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ENVUPDATEREQUEST_USERDATA, _ENVUPDATEREQUEST_AGENTDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=709,
  serialized_end=982,
)


_ENVUPDATEREPLY = _descriptor.Descriptor(
  name='EnvUpdateReply',
  full_name='aom_api.EnvUpdateReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='delta', full_name='aom_api.EnvUpdateReply.delta', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=984,
  serialized_end=1039,
)


_AGENTSTARTREQUEST = _descriptor.Descriptor(
  name='AgentStartRequest',
  full_name='aom_api.AgentStartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='aom_api.AgentStartRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initial_sim_state', full_name='aom_api.AgentStartRequest.initial_sim_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1041,
  serialized_end=1126,
)


_AGENTSTARTREPLY = _descriptor.Descriptor(
  name='AgentStartReply',
  full_name='aom_api.AgentStartReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1128,
  serialized_end=1145,
)


_AGENTREWARDREQUEST = _descriptor.Descriptor(
  name='AgentRewardRequest',
  full_name='aom_api.AgentRewardRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1147,
  serialized_end=1167,
)


_AGENTREWARDREPLY = _descriptor.Descriptor(
  name='AgentRewardReply',
  full_name='aom_api.AgentRewardReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1169,
  serialized_end=1187,
)

_ENVSTATE.fields_by_name['env_specific_data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ENVSTATEDELTA.fields_by_name['env_specific_data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_TRIALSTARTREQUEST.fields_by_name['env_specific_data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_TRIALSTARTREPLY.fields_by_name['env_specific_data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_TRIALSTARTREPLY.fields_by_name['initial_sim_state'].message_type = _ENVSTATE
_ENVSTARTREQUEST.fields_by_name['user_request'].message_type = _TRIALSTARTREQUEST
_ENVSTARTREPLY.fields_by_name['initial_sim_state'].message_type = _ENVSTATE
_ENVUPDATEREQUEST_USERDATA.fields_by_name['env_specific_data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ENVUPDATEREQUEST_USERDATA.containing_type = _ENVUPDATEREQUEST
_ENVUPDATEREQUEST_AGENTDATA.fields_by_name['env_specific_data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ENVUPDATEREQUEST_AGENTDATA.containing_type = _ENVUPDATEREQUEST
_ENVUPDATEREQUEST.fields_by_name['user_data'].message_type = _ENVUPDATEREQUEST_USERDATA
_ENVUPDATEREQUEST.fields_by_name['agent_data'].message_type = _ENVUPDATEREQUEST_AGENTDATA
_ENVUPDATEREPLY.fields_by_name['delta'].message_type = _ENVSTATEDELTA
_AGENTSTARTREQUEST.fields_by_name['initial_sim_state'].message_type = _ENVSTATE
DESCRIPTOR.message_types_by_name['EnvState'] = _ENVSTATE
DESCRIPTOR.message_types_by_name['EnvStateDelta'] = _ENVSTATEDELTA
DESCRIPTOR.message_types_by_name['RewardEvent'] = _REWARDEVENT
DESCRIPTOR.message_types_by_name['TrialStartRequest'] = _TRIALSTARTREQUEST
DESCRIPTOR.message_types_by_name['TrialStartReply'] = _TRIALSTARTREPLY
DESCRIPTOR.message_types_by_name['TrialActionRequest'] = _TRIALACTIONREQUEST
DESCRIPTOR.message_types_by_name['TrialActionReply'] = _TRIALACTIONREPLY
DESCRIPTOR.message_types_by_name['TrialRewardRequest'] = _TRIALREWARDREQUEST
DESCRIPTOR.message_types_by_name['TrialRewardReply'] = _TRIALREWARDREPLY
DESCRIPTOR.message_types_by_name['EnvStartRequest'] = _ENVSTARTREQUEST
DESCRIPTOR.message_types_by_name['EnvStartReply'] = _ENVSTARTREPLY
DESCRIPTOR.message_types_by_name['EnvUpdateRequest'] = _ENVUPDATEREQUEST
DESCRIPTOR.message_types_by_name['EnvUpdateReply'] = _ENVUPDATEREPLY
DESCRIPTOR.message_types_by_name['AgentStartRequest'] = _AGENTSTARTREQUEST
DESCRIPTOR.message_types_by_name['AgentStartReply'] = _AGENTSTARTREPLY
DESCRIPTOR.message_types_by_name['AgentRewardRequest'] = _AGENTREWARDREQUEST
DESCRIPTOR.message_types_by_name['AgentRewardReply'] = _AGENTREWARDREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EnvState = _reflection.GeneratedProtocolMessageType('EnvState', (_message.Message,), dict(
  DESCRIPTOR = _ENVSTATE,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.EnvState)
  ))
_sym_db.RegisterMessage(EnvState)

EnvStateDelta = _reflection.GeneratedProtocolMessageType('EnvStateDelta', (_message.Message,), dict(
  DESCRIPTOR = _ENVSTATEDELTA,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.EnvStateDelta)
  ))
_sym_db.RegisterMessage(EnvStateDelta)

RewardEvent = _reflection.GeneratedProtocolMessageType('RewardEvent', (_message.Message,), dict(
  DESCRIPTOR = _REWARDEVENT,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.RewardEvent)
  ))
_sym_db.RegisterMessage(RewardEvent)

TrialStartRequest = _reflection.GeneratedProtocolMessageType('TrialStartRequest', (_message.Message,), dict(
  DESCRIPTOR = _TRIALSTARTREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialStartRequest)
  ))
_sym_db.RegisterMessage(TrialStartRequest)

TrialStartReply = _reflection.GeneratedProtocolMessageType('TrialStartReply', (_message.Message,), dict(
  DESCRIPTOR = _TRIALSTARTREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialStartReply)
  ))
_sym_db.RegisterMessage(TrialStartReply)

TrialActionRequest = _reflection.GeneratedProtocolMessageType('TrialActionRequest', (_message.Message,), dict(
  DESCRIPTOR = _TRIALACTIONREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialActionRequest)
  ))
_sym_db.RegisterMessage(TrialActionRequest)

TrialActionReply = _reflection.GeneratedProtocolMessageType('TrialActionReply', (_message.Message,), dict(
  DESCRIPTOR = _TRIALACTIONREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialActionReply)
  ))
_sym_db.RegisterMessage(TrialActionReply)

TrialRewardRequest = _reflection.GeneratedProtocolMessageType('TrialRewardRequest', (_message.Message,), dict(
  DESCRIPTOR = _TRIALREWARDREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialRewardRequest)
  ))
_sym_db.RegisterMessage(TrialRewardRequest)

TrialRewardReply = _reflection.GeneratedProtocolMessageType('TrialRewardReply', (_message.Message,), dict(
  DESCRIPTOR = _TRIALREWARDREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.TrialRewardReply)
  ))
_sym_db.RegisterMessage(TrialRewardReply)

EnvStartRequest = _reflection.GeneratedProtocolMessageType('EnvStartRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENVSTARTREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.EnvStartRequest)
  ))
_sym_db.RegisterMessage(EnvStartRequest)

EnvStartReply = _reflection.GeneratedProtocolMessageType('EnvStartReply', (_message.Message,), dict(
  DESCRIPTOR = _ENVSTARTREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.EnvStartReply)
  ))
_sym_db.RegisterMessage(EnvStartReply)

EnvUpdateRequest = _reflection.GeneratedProtocolMessageType('EnvUpdateRequest', (_message.Message,), dict(

  UserData = _reflection.GeneratedProtocolMessageType('UserData', (_message.Message,), dict(
    DESCRIPTOR = _ENVUPDATEREQUEST_USERDATA,
    __module__ = 'aom_framework.protocols_pb2'
    # @@protoc_insertion_point(class_scope:aom_api.EnvUpdateRequest.UserData)
    ))
  ,

  AgentData = _reflection.GeneratedProtocolMessageType('AgentData', (_message.Message,), dict(
    DESCRIPTOR = _ENVUPDATEREQUEST_AGENTDATA,
    __module__ = 'aom_framework.protocols_pb2'
    # @@protoc_insertion_point(class_scope:aom_api.EnvUpdateRequest.AgentData)
    ))
  ,
  DESCRIPTOR = _ENVUPDATEREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.EnvUpdateRequest)
  ))
_sym_db.RegisterMessage(EnvUpdateRequest)
_sym_db.RegisterMessage(EnvUpdateRequest.UserData)
_sym_db.RegisterMessage(EnvUpdateRequest.AgentData)

EnvUpdateReply = _reflection.GeneratedProtocolMessageType('EnvUpdateReply', (_message.Message,), dict(
  DESCRIPTOR = _ENVUPDATEREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.EnvUpdateReply)
  ))
_sym_db.RegisterMessage(EnvUpdateReply)

AgentStartRequest = _reflection.GeneratedProtocolMessageType('AgentStartRequest', (_message.Message,), dict(
  DESCRIPTOR = _AGENTSTARTREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.AgentStartRequest)
  ))
_sym_db.RegisterMessage(AgentStartRequest)

AgentStartReply = _reflection.GeneratedProtocolMessageType('AgentStartReply', (_message.Message,), dict(
  DESCRIPTOR = _AGENTSTARTREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.AgentStartReply)
  ))
_sym_db.RegisterMessage(AgentStartReply)

AgentRewardRequest = _reflection.GeneratedProtocolMessageType('AgentRewardRequest', (_message.Message,), dict(
  DESCRIPTOR = _AGENTREWARDREQUEST,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.AgentRewardRequest)
  ))
_sym_db.RegisterMessage(AgentRewardRequest)

AgentRewardReply = _reflection.GeneratedProtocolMessageType('AgentRewardReply', (_message.Message,), dict(
  DESCRIPTOR = _AGENTREWARDREPLY,
  __module__ = 'aom_framework.protocols_pb2'
  # @@protoc_insertion_point(class_scope:aom_api.AgentRewardReply)
  ))
_sym_db.RegisterMessage(AgentRewardReply)


# @@protoc_insertion_point(module_scope)



# Copyright 2019 Age of Minds inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(name='aom_sdk',
      version='0.0.3',
      description='AoM platform sdk',
      url='https://gitlab.com/age-of-minds/aom-framework',
      long_description=long_description,
      long_description_content_type="text/markdown",
      author='Age of Minds',
      author_email='dev@ageofminds.com',
      license='Apache License 2.0',
      packages=[
          'aom_framework',
          'aom_framework.agent_service',
          'aom_framework.env_service'],
      install_requires=[
          'grpcio>=1.19',
          'protobuf>=3.7'
      ],)